pub struct CryptoExchangeFact {
pub version: u64,
pub exchanges: Arc<[CryptoExchangeInfo]>,
pub positive_lv2_prob_sum: Option<i32>,
}Expand description
Immutable request-level view of one exact (stock_id, broker_id) fact.
The writer publishes version, exact vector, and aggregate as one DashMap value.
Fields
version: u64exchanges: Arc<[CryptoExchangeInfo]>positive_lv2_prob_sum: Option<i32>Trait Implementations
Sourceimpl Clone for CryptoExchangeFact
impl Clone for CryptoExchangeFact
Sourcefn clone(&self) -> CryptoExchangeFact
fn clone(&self) -> CryptoExchangeFact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CryptoExchangeFact
impl Debug for CryptoExchangeFact
Sourceimpl PartialEq for CryptoExchangeFact
impl PartialEq for CryptoExchangeFact
Sourcefn eq(&self, other: &CryptoExchangeFact) -> bool
fn eq(&self, other: &CryptoExchangeFact) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CryptoExchangeFact