pub struct CachedSpreadBand {
pub price_from: i64,
pub price_to: i64,
pub value: i64,
}Expand description
C++ INNData_Qot_Spread cached price-grid row.
Backend CMD6503 uses 1e9 fixed-point integers for price_from /
price_to / value. QotRealTimeData::ParsePrice and
APIServer_Qot_StockSnapshot pass current price in the same scale to
INNBiz_Qot_Spread::AdjustPrice, then expose priceSpread = value / 1e9.
Fields
price_from: i64price_to: i64value: i64Trait Implementations
Sourceimpl Clone for CachedSpreadBand
impl Clone for CachedSpreadBand
Sourcefn clone(&self) -> CachedSpreadBand
fn clone(&self) -> CachedSpreadBand
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CachedSpreadBand
Sourceimpl Debug for CachedSpreadBand
impl Debug for CachedSpreadBand
impl Eq for CachedSpreadBand
Sourceimpl PartialEq for CachedSpreadBand
impl PartialEq for CachedSpreadBand
Sourcefn eq(&self, other: &CachedSpreadBand) -> bool
fn eq(&self, other: &CachedSpreadBand) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CachedSpreadBand