pub struct FreshDigitalFutureEntitlement {
pub backend_generation: u64,
pub source_publication_epoch: Option<u64>,
pub has_digital_future_auth: bool,
}Expand description
One causally consistent entitlement fact read under the cache’s canonical
data -> meta lock order.
Callers that derive a backend request from this value must additionally take the snapshot under the owning Platform route-publication terminal. That couples the entitlement generation to the route used for the request without holding cache locks across network I/O.
Fields
backend_generation: u64source_publication_epoch: Option<u64>has_digital_future_auth: boolTrait Implementations
Sourceimpl Clone for FreshDigitalFutureEntitlement
impl Clone for FreshDigitalFutureEntitlement
Sourcefn clone(&self) -> FreshDigitalFutureEntitlement
fn clone(&self) -> FreshDigitalFutureEntitlement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FreshDigitalFutureEntitlement
impl Eq for FreshDigitalFutureEntitlement
Sourceimpl PartialEq for FreshDigitalFutureEntitlement
impl PartialEq for FreshDigitalFutureEntitlement
Sourcefn eq(&self, other: &FreshDigitalFutureEntitlement) -> bool
fn eq(&self, other: &FreshDigitalFutureEntitlement) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FreshDigitalFutureEntitlement