pub struct BindResult {
pub save_error: Option<String>,
pub load_error: Option<String>,
}Fields
save_error: Option<String>Failure to save the retired identity is observable but never permits that identity to remain active after a login/generation switch.
load_error: Option<String>Corrupt/unreadable new-user last-good is observable but never prevents the clean in-memory identity from becoming current.