pub struct CachedOrderFill {Show 15 fields
pub fill_id: u64,
pub fill_id_ex: String,
pub order_id: u64,
pub order_id_ex: String,
pub code: String,
pub name: String,
pub trd_side: i32,
pub qty: f64,
pub price: f64,
pub create_timestamp: Option<f64>,
pub update_timestamp: Option<f64>,
pub counter_broker_id: Option<i32>,
pub status: Option<i32>,
pub trd_market: Option<i32>,
pub jp_acc_type: Option<i32>,
}Expand description
Cached current-order fill row, matching the public/backend projection used by current fill queries and direct fill notifications.
Fields
fill_id: u64fill_id_ex: Stringorder_id: u64order_id_ex: Stringcode: Stringname: Stringtrd_side: i32qty: f64price: f64create_timestamp: Option<f64>update_timestamp: Option<f64>counter_broker_id: Option<i32>status: Option<i32>trd_market: Option<i32>jp_acc_type: Option<i32>Trait Implementations
Sourceimpl Clone for CachedOrderFill
impl Clone for CachedOrderFill
Sourcefn clone(&self) -> CachedOrderFill
fn clone(&self) -> CachedOrderFill
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CachedOrderFill
impl Debug for CachedOrderFill
Sourceimpl Default for CachedOrderFill
impl Default for CachedOrderFill
Sourcefn default() -> CachedOrderFill
fn default() -> CachedOrderFill
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CachedOrderFill
impl PartialEq for CachedOrderFill
Sourcefn eq(&self, other: &CachedOrderFill) -> bool
fn eq(&self, other: &CachedOrderFill) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CachedOrderFill